# -*- coding: utf-8 -*-

import os, sys

from paver.easy import task, consume_args, path


def init(env):
    # Initialize the paver environment
    pass


@task
def test_runner(options):
    os.environ['DJANGO_SETTINGS_MODULE'] = 'tests.settings'

    args = ['--tb', 'native']
    if options.get('xunit-file'):
        args.extend(['--junit-xml', options['xunit-file']])
    if options.get('with-coverage'):
        args.append('--cov')
    if options.get('xcoverage-file'):
        args.extend(['--cov', '--cov-report', 'xml:{}'.format(options['xcoverage-file'])])

    import pytest
    return_code = pytest.main(args)
    if return_code != 0:
        sys.exit(return_code)


def find_version(filename):
    filepath = os.path.join(os.path.dirname(__file__), filename)
    with open(filepath, 'r') as init:
        for line in init:
            if line.startswith('__version__'):
                x, version = line.split('=', 1)
                return version.strip().strip('\'"')
        else:
            raise ValueError('Cannot find the version in {0}'.format(filename))


def parse_requirements(requirements_txt):
    requirements = []
    try:
        with open(requirements_txt, 'r') as f:
            for line in f:
                line = line.strip()
                if line.startswith('#') or not line:
                    continue
                if line.startswith('-'):
                    raise ValueError('Unexpected command {0} in {1}'.format(
                        line,
                        requirements_txt,
                    ))

                requirements.append(line)
        return requirements
    except IOError:
        return []


@task
def setup_options():
    import setuptools
    from paver.setuputils import setup
    readme_md = os.path.join(os.path.dirname(__file__), 'README.md')
    with open(readme_md, 'r') as readme_file:
        readme = readme_file.read()

    setup(
        name='autodoc',
        version=find_version('autodoc/__init__.py'),
        description='A Django REST Framework instrospection tool that generates an OpenAPI schema',
        long_description=readme,
        author='Grégoire ROCHER',
        author_email='gr@enix.org',
        packages=setuptools.find_packages(
            exclude=[
                'tests',
                'tests.*',
            ],
        ),
        include_package_data=True,
        install_requires=parse_requirements('requirements.txt'),
        zip_safe=False,
    )

if path(sys.argv[0]).realpath() == path(__file__).dirname().joinpath('setup.py').realpath():
    setup_options()


try:
    import sett
    with open(sett.ROOT.joinpath('localpavement.py'), 'r') as localpavement:
        exec(localpavement.read(), locals(), globals())
except (OSError, ImportError) as e:
    pass
